summaryrefslogtreecommitdiffstats
path: root/build/update-apps.sh
diff options
context:
space:
mode:
Diffstat (limited to 'build/update-apps.sh')
-rwxr-xr-xbuild/update-apps.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/build/update-apps.sh b/build/update-apps.sh
index e4611a79aff..2d9e6307c04 100755
--- a/build/update-apps.sh
+++ b/build/update-apps.sh
@@ -1,14 +1,14 @@
#!/bin/bash
# Update Nextcloud apps from latest git master
# For local development environment
# Use from Nextcloud server folder with `./build/update-apps.sh`
#
# It automatically:
# - goes through all apps which are not shipped via server
# - shows the app name in bold and uses whitespace for separation
# - changes to master and pulls quietly
# - shows the 3 most recent commits for context
# - removes branches merged into master
# - … could even do the build steps if they are consistent for the apps (like `make`)
-find apps* -maxdepth 2 -name .git -exec sh -c 'cd {}/../ && printf "\n\033[1m${PWD##*/}\033[0m\n" && git checkout master && git pull --quiet -p && git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s" && printf "\n" && git branch --merged master | grep -v "master$" | xargs git branch -d && cd ..' \;
+find apps* -maxdepth 2 -name .git -exec sh -c 'cd {}/../ && printf "\n\033[1m${PWD##*/}\033[0m\n" && git checkout stable29 && git pull --quiet -p && git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s" && printf "\n" && git branch --merged stable29 | grep -v "stable29$" | xargs git branch -d && cd ..' \;
@@ -1,14 +1,14 @@
#!/bin/bash
-# Update Nextcloud apps from latest git master
+# Update Nextcloud apps from latest git stable29
# For local development environment
# Use from Nextcloud server folder with `./build/update-apps.sh`
@@ -1,14 +1,14 @@
# - goes through all apps which are not shipped via server
# - shows the app name in bold and uses whitespace for separation
-# - changes to master and pulls quietly
+# - changes to stable29 and pulls quietly
# - shows the 3 most recent commits for context
@@ -1,14 +1,14 @@
# - shows the 3 most recent commits for context
-# - removes branches merged into master
+# - removes branches merged into stable29
# - … could even do the build steps if they are consistent for the apps (like `make`)